@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -60,7 +60,7 @@ static void     gpk_check_update_finalize	(GObject	     *object);
 #define GPK_CHECK_UPDATE_MAX_NUMBER_SECURITY_ENTRIES	7
 
 /* the amount of time after ::UpdatesChanged we refresh the update list */
-#define GPK_CHECK_UPDATE_UPDATES_CHANGED_TIMEOUT	60 /* seconds */
+#define GPK_CHECK_UPDATE_UPDATES_CHANGED_TIMEOUT	3 /* seconds */
 
 struct GpkCheckUpdatePrivate
 {
@@ -172,50 +172,11 @@ gpk_check_update_show_preferences_cb (GtkMenuItem *item, GpkCheckUpdate *cupdate
 		egg_warning ("Couldn't execute command: %s", command);
 }
 
-/**
- * gpk_check_update_about_dialog_url_cb:
- **/
-static void
-gpk_check_update_about_dialog_url_cb (GtkAboutDialog *about, const char *address, gpointer data)
-{
-	GError *error = NULL;
-	gboolean ret;
-	GdkScreen *gscreen;
-	GtkWidget *error_dialog;
-	gchar *url;
-	gchar *protocol = (gchar*) data;
-
-	if (protocol != NULL)
-		url = g_strconcat (protocol, address, NULL);
-	else
-		url = g_strdup (address);
-
-	gscreen = gtk_window_get_screen (GTK_WINDOW (about));
-
-	ret = gtk_show_uri (gscreen, url, gtk_get_current_event_time (), &error);
-
-	if (!ret) {
-		error_dialog = gtk_message_dialog_new (GTK_WINDOW (about),
-						       GTK_DIALOG_MODAL,
-						       GTK_MESSAGE_INFO,
-						       GTK_BUTTONS_OK,
-						       /* TRANSLATORS: normally a packaging error, cannot launch link */
-						       _("Failed to show url"));
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog),
-							  "%s", error->message);
-		gtk_dialog_run (GTK_DIALOG (error_dialog));
-		gtk_widget_destroy (error_dialog);
-		g_error_free (error);
-	}
-
-	g_free (url);
-}
-
 /**
  * gpk_check_update_show_about_cb:
  **/
 static void
-gpk_check_update_show_about_cb (GtkMenuItem *item, gpointer data)
+gpk_check_update_show_about_cb (GtkMenuItem *item, GpkCheckUpdate *icon)
 {
 	const char *authors[] = {
 		"Richard Hughes <richard@hughsie.com>",
@@ -248,9 +209,6 @@ gpk_check_update_show_about_cb (GtkMenuItem *item, gpointer data)
 	license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
 				     _(license[2]), "\n\n", _(license[3]), "\n",  NULL);
 
-	gtk_about_dialog_set_url_hook (gpk_check_update_about_dialog_url_cb, NULL, NULL);
-	gtk_about_dialog_set_email_hook (gpk_check_update_about_dialog_url_cb, (gpointer) "mailto:", NULL);
-
 	gtk_window_set_default_icon_name (GPK_ICON_SOFTWARE_UPDATE);
 	gtk_show_about_dialog (NULL,
 			       "version", VERSION,
@@ -259,7 +217,7 @@ gpk_check_update_show_about_cb (GtkMenuItem *item, gpointer data)
 			       "wrap-license", TRUE,
 				/* TRANSLATORS: website label */
 			       "website-label", _("PackageKit Website"),
-			       "website", "www.packagekit.org",
+			       "website", "http://www.packagekit.org",
 			       "comments", "PackageKit",
 			       "authors", authors,
 			       "documenters", documenters,
