@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -25,15 +25,14 @@
 #include <glib/gi18n.h>
 #include <locale.h>
 
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <math.h>
 #include <string.h>
 #include <dbus/dbus-glib.h>
 #include <gconf/gconf-client.h>
 #include <packagekit-glib/packagekit.h>
+#include <unique/unique.h>
 
-#include "egg-unique.h"
 #include "egg-debug.h"
 #include "egg-string.h"
 
@@ -43,22 +42,37 @@
 #include "gpk-animated-icon.h"
 #include "gpk-enum.h"
 
-static GladeXML *glade_xml = NULL;
+static GtkBuilder *builder = NULL;
 static GtkListStore *list_store = NULL;
-static PkClient *client = NULL;
+static PkClient *client_query = NULL;
+#if PK_CHECK_VERSION(0,5,1)
+static PkClientPool *pool = NULL;
+#else
+static GPtrArray *client_array = NULL;
+#endif
 static PkBitfield roles;
 static GConfClient *gconf_client;
 static gboolean show_details;
 static GtkTreePath *path_global = NULL;
+static GtkWidget *image_animation = NULL;
+#if !PK_CHECK_VERSION(0,5,1)
+static PkStatusEnum status_last = PK_STATUS_ENUM_UNKNOWN;
+#endif
+static guint status_id = 0;
 
 enum {
 	REPO_COLUMN_ENABLED,
 	REPO_COLUMN_TEXT,
 	REPO_COLUMN_ID,
 	REPO_COLUMN_ACTIVE,
+	REPO_COLUMN_SENSITIVE,
 	REPO_COLUMN_LAST
 };
 
+#if !PK_CHECK_VERSION(0,5,1)
+static PkClient *gpk_repo_create_client (void);
+#endif
+
 /**
  * gpk_repo_find_iter_model_cb:
  **/
@@ -151,45 +165,40 @@ gpk_button_help_cb (GtkWidget *widget, gboolean  data)
 }
 
 static void
-gpk_misc_installed_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
+gpk_misc_enabled_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
 {
-	GtkWidget *widget;
 	GtkTreeModel *model = (GtkTreeModel *)data;
 	GtkTreeIter iter;
 	GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
-	gboolean installed;
-	gchar *repo_id;
+	gboolean enabled;
+	gchar *repo_id = NULL;
 	gboolean ret;
 	GError *error = NULL;
+	PkClient *client = NULL;
 
 	/* do we have the capability? */
 	if (pk_bitfield_contain (roles, PK_ROLE_ENUM_REPO_ENABLE) == FALSE) {
 		egg_debug ("can't change state");
-		return;
+		goto out;
 	}
 
-	/* set insensitive until we've done this */
-	widget = glade_xml_get_widget (glade_xml, "treeview_repo");
-	gtk_widget_set_sensitive (widget, FALSE);
-
 	/* get toggled iter */
 	gtk_tree_model_get_iter (model, &iter, path);
 	gtk_tree_model_get (model, &iter,
-			    REPO_COLUMN_ENABLED, &installed,
+			    REPO_COLUMN_ENABLED, &enabled,
 			    REPO_COLUMN_ID, &repo_id, -1);
 
 	/* do something with the value */
-	installed ^= 1;
+	enabled ^= 1;
 
 	/* do this to the repo */
-	egg_debug ("setting %s to %i", repo_id, installed);
-	ret = pk_client_reset (client, &error);
-	if (!ret) {
-		egg_warning ("failed to reset client: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-	ret = pk_client_repo_enable (client, repo_id, installed, &error);
+	egg_debug ("setting %s to %i", repo_id, enabled);
+#if PK_CHECK_VERSION(0,5,1)
+	client = pk_client_pool_create (pool);
+#else
+	client = gpk_repo_create_client ();
+#endif
+	ret = pk_client_repo_enable (client, repo_id, enabled, &error);
 	if (!ret) {
 		egg_warning ("could not set repo enabled state: %s", error->message);
 		g_error_free (error);
@@ -197,10 +206,14 @@ gpk_misc_installed_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpoint
 	}
 
 	/* set new value */
-	gtk_list_store_set (GTK_LIST_STORE(model), &iter, REPO_COLUMN_ENABLED, installed, -1);
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+			    REPO_COLUMN_SENSITIVE, FALSE,
+			    -1);
 
 out:
 	/* clean up */
+	if (client != NULL)
+		g_object_unref (client);
 	g_free (repo_id);
 	gtk_tree_path_free (path);
 }
@@ -209,11 +222,11 @@ out:
  * gpk_repo_detail_cb:
  **/
 static void
-gpk_repo_detail_cb (PkClient *client_, const gchar *repo_id,
+gpk_repo_detail_cb (PkClient *client, const gchar *repo_id,
 		    const gchar *description, gboolean enabled, gpointer data)
 {
 	GtkTreeIter iter;
-	GtkTreeView *treeview = GTK_TREE_VIEW (glade_xml_get_widget (glade_xml, "treeview_repo"));
+	GtkTreeView *treeview = GTK_TREE_VIEW (gtk_builder_get_object (builder, "treeview_repo"));
 	GtkTreeModel *model = gtk_tree_view_get_model (treeview);
 
 	egg_debug ("repo = %s:%s:%i", repo_id, description, enabled);
@@ -224,6 +237,7 @@ gpk_repo_detail_cb (PkClient *client_, const gchar *repo_id,
 			    REPO_COLUMN_TEXT, description,
 			    REPO_COLUMN_ID, repo_id,
 			    REPO_COLUMN_ACTIVE, TRUE,
+			    REPO_COLUMN_SENSITIVE, TRUE,
 			    -1);
 
 	/* sort after each entry, which is okay as there shouldn't be many */
@@ -240,13 +254,15 @@ gpk_treeview_add_columns (GtkTreeView *treeview)
 	GtkTreeViewColumn *column;
 	GtkTreeModel *model = gtk_tree_view_get_model (treeview);
 
-	/* column for installed toggles */
+	/* column for enabled toggles */
 	renderer = gtk_cell_renderer_toggle_new ();
-	g_signal_connect (renderer, "toggled", G_CALLBACK (gpk_misc_installed_toggled), model);
+	g_signal_connect (renderer, "toggled", G_CALLBACK (gpk_misc_enabled_toggled), model);
 
 	/* TRANSLATORS: column if the source is enabled */
 	column = gtk_tree_view_column_new_with_attributes (_("Enabled"), renderer,
-							   "active", REPO_COLUMN_ENABLED, NULL);
+							   "active", REPO_COLUMN_ENABLED,
+							   "sensitive", REPO_COLUMN_SENSITIVE,
+							   NULL);
 	gtk_tree_view_append_column (treeview, column);
 
 	/* column for text */
@@ -282,61 +298,95 @@ gpk_repos_treeview_clicked_cb (GtkTreeSelection *selection, gpointer data)
  * gpk_repo_finished_cb:
  **/
 static void
-gpk_repo_finished_cb (PkClient *client_, PkExitEnum exit, guint runtime, gpointer data)
+gpk_repo_finished_cb (PkClient *client, PkExitEnum exit, guint runtime, gpointer data)
 {
 	GtkTreeView *treeview;
 	GtkTreeModel *model;
-	GtkWidget *widget;
-
-	/* set sensitive now we've done this */
-	widget = glade_xml_get_widget (glade_xml, "treeview_repo");
-	gtk_widget_set_sensitive (widget, TRUE);
 
 	/* remove the items that are not used */
-	treeview = GTK_TREE_VIEW (glade_xml_get_widget (glade_xml, "treeview_repo"));
+	treeview = GTK_TREE_VIEW (gtk_builder_get_object (builder, "treeview_repo"));
 	model = gtk_tree_view_get_model (treeview);
 	gpk_repo_remove_nonactive (model);
 }
 
+/**
+ * gpk_repo_status_changed_timeout_cb:
+ **/
+static gboolean
+gpk_repo_status_changed_timeout_cb (PkClient *client)
+{
+	const gchar *text;
+	GtkWidget *widget;
+	PkStatusEnum status;
+
+#if PK_CHECK_VERSION(0,5,1)
+	/* get the last status */
+	g_object_get (client,
+		      "status", &status,
+		      NULL);
+#else
+	status = status_last;
+#endif
+
+	/* set the text and show */
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "viewport_animation_preview"));
+	gtk_widget_show (widget);
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "label_animation"));
+	text = gpk_status_enum_to_localised_text (status);
+	gtk_label_set_label (GTK_LABEL (widget), text);
+
+	/* set icon */
+	gpk_set_animated_icon_from_status (GPK_ANIMATED_ICON (image_animation), status, GTK_ICON_SIZE_LARGE_TOOLBAR);
+
+	/* never repeat */
+	status_id = 0;
+	return FALSE;
+}
+
 /**
  * gpk_repo_status_changed_cb:
  **/
 static void
-gpk_repo_status_changed_cb (PkClient *client_, PkStatusEnum status, gpointer data)
+gpk_repo_status_changed_cb (PkClient *client, PkStatusEnum status, gpointer data)
 {
-	const gchar *text;
 	GtkWidget *widget;
 
-	widget = glade_xml_get_widget (glade_xml, "viewport_animation_preview");
 	if (status == PK_STATUS_ENUM_FINISHED) {
+		/* we've not yet shown, so don't bother */
+		if (status_id > 0) {
+			g_source_remove (status_id);
+			status_id = 0;
+		}
+		widget = GTK_WIDGET (gtk_builder_get_object (builder, "viewport_animation_preview"));
 		gtk_widget_hide (widget);
-		widget = glade_xml_get_widget (glade_xml, "image_animation");
-		gpk_animated_icon_enable_animation (GPK_ANIMATED_ICON (widget), FALSE);
-		return;
+		gpk_animated_icon_enable_animation (GPK_ANIMATED_ICON (image_animation), FALSE);
+		goto out;
 	}
 
-	/* set the text and show */
-	gtk_widget_show (widget);
-	widget = glade_xml_get_widget (glade_xml, "label_animation");
-	text = gpk_status_enum_to_localised_text (status);
-	gtk_label_set_label (GTK_LABEL (widget), text);
+	/* already pending show */
+	if (status_id > 0)
+		goto out;
 
-	/* set icon */
-	widget = glade_xml_get_widget (glade_xml, "image_animation");
-	gpk_set_animated_icon_from_status (GPK_ANIMATED_ICON (widget), status, GTK_ICON_SIZE_LARGE_TOOLBAR);
-	gtk_widget_show (widget);
+	/* only show after some time in the transaction */
+	status_id = g_timeout_add (GPK_UI_STATUS_SHOW_DELAY, (GSourceFunc) gpk_repo_status_changed_timeout_cb, client);
+out:
+#if !PK_CHECK_VERSION(0,5,1)
+	/* save for the callback */
+	status_last = status;
+#endif
+	return;
 }
 
 /**
  * gpk_repo_error_code_cb:
  **/
 static void
-gpk_repo_error_code_cb (PkClient *client_, PkErrorCodeEnum code, const gchar *details, gpointer data)
+gpk_repo_error_code_cb (PkClient *client, PkErrorCodeEnum code, const gchar *details, gpointer data)
 {
-	GtkWidget *widget;
-	widget = glade_xml_get_widget (glade_xml, "dialog_repo");
+	GtkWindow *window;
+	window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_repo"));
 	/* TRANSLATORS: for one reason or another, we could not enable or disable a software source */
-	gpk_error_dialog_modal (GTK_WINDOW (widget), _("Failed to change status"),
+	gpk_error_dialog_modal (window, _("Failed to change status"),
 				gpk_error_enum_to_localised_text (code), details);
 }
 
@@ -353,12 +403,12 @@ gpk_repo_repo_list_refresh (void)
 	GtkTreeModel *model;
 
 	/* mark the items as not used */
-	treeview = GTK_TREE_VIEW (glade_xml_get_widget (glade_xml, "treeview_repo"));
+	treeview = GTK_TREE_VIEW (gtk_builder_get_object (builder, "treeview_repo"));
 	model = gtk_tree_view_get_model (treeview);
 	gpk_repo_mark_nonactive (model);
 
 	egg_debug ("refreshing list");
-	ret = pk_client_reset (client, &error);
+	ret = pk_client_reset (client_query, &error);
 	if (!ret) {
 		egg_warning ("failed to reset client: %s", error->message);
 		g_error_free (error);
@@ -368,7 +418,7 @@ gpk_repo_repo_list_refresh (void)
 		filters = pk_bitfield_value (PK_FILTER_ENUM_NOT_DEVELOPMENT);
 	else
 		filters = pk_bitfield_value (PK_FILTER_ENUM_NONE);
-	ret = pk_client_get_repo_list (client, filters, &error);
+	ret = pk_client_get_repo_list (client_query, filters, &error);
 	if (!ret) {
 		egg_warning ("failed to get repo list: %s", error->message);
 		g_error_free (error);
@@ -397,29 +447,55 @@ gpk_repo_checkbutton_details (GtkWidget *widget, gpointer data)
 }
 
 /**
- * gpk_repo_activated_cb
+ * gpk_repo_message_received_cb
  **/
 static void
-gpk_repo_activated_cb (EggUnique *egg_unique, gpointer data)
+gpk_repo_message_received_cb (UniqueApp *app, UniqueCommand command, UniqueMessageData *message_data, guint time_ms, gpointer data)
 {
-	GtkWidget *widget;
-	widget = glade_xml_get_widget (glade_xml, "dialog_repo");
-	gtk_window_present (GTK_WINDOW (widget));
+	GtkWindow *window;
+	if (command == UNIQUE_ACTIVATE) {
+		window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_repo"));
+		gtk_window_present (window);
+	}
+}
+
+#if !PK_CHECK_VERSION(0,5,1)
+/**
+ * gpk_repo_destroy_cb:
+ **/
+static void
+gpk_repo_destroy_cb (PkClient *client, gpointer data)
+{
+	gboolean ret;
+	egg_debug ("client destroyed");
+	ret = g_ptr_array_remove (client_array, client);
+	if (!ret)
+		egg_warning ("failed to remove %p", client);
+	/* TODO: disconnect signals? */
+	g_object_unref (client);
 }
 
 /**
- * gpk_repo_create_custom_widget:
+ * gpk_repo_create_client
  **/
-static GtkWidget *
-gpk_repo_create_custom_widget (GladeXML *xml, gchar *func_name, gchar *name,
-			       gchar *string1, gchar *string2,
-			       gint int1, gint int2, gpointer user_data)
+static PkClient *
+gpk_repo_create_client (void)
 {
-	if (egg_strequal (name, "image_animation"))
-		return gpk_animated_icon_new ();
-	egg_warning ("name unknown='%s'", name);
-	return NULL;
+	PkClient *client;
+	client = pk_client_new ();
+	g_signal_connect (client, "repo-detail",
+			  G_CALLBACK (gpk_repo_detail_cb), NULL);
+	g_signal_connect (client, "status-changed",
+			  G_CALLBACK (gpk_repo_status_changed_cb), NULL);
+	g_signal_connect (client, "error-code",
+			  G_CALLBACK (gpk_repo_error_code_cb), NULL);
+	g_signal_connect (client, "destroy",
+			  G_CALLBACK (gpk_repo_destroy_cb), NULL);
+	g_ptr_array_add (client_array, client);
+	egg_debug ("added %p", client);
+	return g_object_ref (client);
 }
+#endif
 
 /**
  * main:
@@ -433,12 +509,19 @@ main (int argc, char *argv[])
 	GtkWidget *widget;
 	GtkTreeSelection *selection;
 	PkControl *control;
-	EggUnique *egg_unique;
+	UniqueApp *unique_app;
+	GError *error = NULL;
+	guint retval;
+	guint xid = 0;
 	gboolean ret;
+	GtkBox *box;
 
 	const GOptionEntry options[] = {
 		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
 		  _("Show extra debugging information"), NULL },
+		{ "parent-window", 'p', 0, G_OPTION_ARG_INT, &xid,
+		  /* TRANSLATORS: we can make this modal (stay on top of) another window */
+		  _("Set the parent window to make this modal"), NULL },
 		{ NULL}
 	};
 
@@ -472,47 +555,71 @@ main (int argc, char *argv[])
                                            GPK_DATA G_DIR_SEPARATOR_S "icons");
 
 	/* are we already activated? */
-	egg_unique = egg_unique_new ();
-	ret = egg_unique_assign (egg_unique, "org.freedesktop.PackageKit.Repo");
-	if (!ret)
+	unique_app = unique_app_new ("org.freedesktop.PackageKit.Repo", NULL);
+	if (unique_app_is_running (unique_app)) {
+		egg_debug ("You have another instance running. This program will now close");
+		unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
 		goto unique_out;
-	g_signal_connect (egg_unique, "activated",
-			  G_CALLBACK (gpk_repo_activated_cb), NULL);
+	}
+	g_signal_connect (unique_app, "message-received",
+			  G_CALLBACK (gpk_repo_message_received_cb), NULL);
 
 	gconf_client = gconf_client_get_default ();
 
-	client = pk_client_new ();
-	g_signal_connect (client, "repo-detail",
+	client_query = pk_client_new ();
+	g_signal_connect (client_query, "repo-detail",
 			  G_CALLBACK (gpk_repo_detail_cb), NULL);
-	g_signal_connect (client, "status-changed",
+	g_signal_connect (client_query, "status-changed",
 			  G_CALLBACK (gpk_repo_status_changed_cb), NULL);
-	g_signal_connect (client, "finished",
+	g_signal_connect (client_query, "finished",
 			  G_CALLBACK (gpk_repo_finished_cb), NULL);
-	g_signal_connect (client, "error-code",
+	g_signal_connect (client_query, "error-code",
 			  G_CALLBACK (gpk_repo_error_code_cb), NULL);
 
+#if PK_CHECK_VERSION(0,5,1)
+	pool = pk_client_pool_new ();
+	pk_client_pool_connect (pool, "repo-detail",
+				G_CALLBACK (gpk_repo_detail_cb), NULL);
+	pk_client_pool_connect (pool, "status-changed",
+				G_CALLBACK (gpk_repo_status_changed_cb), NULL);
+	pk_client_pool_connect (pool, "error-code",
+				G_CALLBACK (gpk_repo_error_code_cb), NULL);
+#else
+	client_array = g_ptr_array_new ();
+#endif
+
 	control = pk_control_new ();
 	g_signal_connect (control, "repo-list-changed",
 			  G_CALLBACK (gpk_repo_repo_list_changed_cb), NULL);
 	roles = pk_control_get_actions (control, NULL);
 
-	/* use custom widgets */
-	glade_set_custom_handler (gpk_repo_create_custom_widget, NULL);
+	/* get UI */
+	builder = gtk_builder_new ();
+	retval = gtk_builder_add_from_file (builder, GPK_DATA "/gpk-repo.ui", &error);
+	if (error != NULL) {
+		egg_warning ("failed to load ui: %s", error->message);
+		g_error_free (error);
+		goto out_build;
+	}
 
-	glade_xml = glade_xml_new (GPK_DATA "/gpk-repo.glade", NULL, NULL);
-	main_window = glade_xml_get_widget (glade_xml, "dialog_repo");
+	/* add animated widget */
+	image_animation = gpk_animated_icon_new ();
+	box = GTK_BOX (gtk_builder_get_object (builder, "hbox_animation"));
+	gtk_box_pack_start (box, image_animation, FALSE, FALSE, 0);
+	gtk_box_reorder_child (box, image_animation, 0);
+	gtk_widget_show (image_animation);
+
+	main_window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_repo"));
 	gtk_window_set_icon_name (GTK_WINDOW (main_window), GPK_ICON_SOFTWARE_SOURCES);
-
-	/* Get the main window quit */
 	g_signal_connect_swapped (main_window, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
 
-	widget = glade_xml_get_widget (glade_xml, "button_close");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
 	g_signal_connect_swapped (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
-	widget = glade_xml_get_widget (glade_xml, "button_help");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpk_button_help_cb), NULL);
 
-	widget = glade_xml_get_widget (glade_xml, "checkbutton_detail");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_detail"));
 	show_details = gconf_client_get_bool (gconf_client, GPK_CONF_REPO_SHOW_DETAILS, NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), show_details);
 	g_signal_connect (widget, "clicked",
@@ -523,10 +630,10 @@ main (int argc, char *argv[])
 
 	/* create list stores */
 	list_store = gtk_list_store_new (REPO_COLUMN_LAST, G_TYPE_BOOLEAN,
-					 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
+					 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
 
 	/* create repo tree view */
-	widget = glade_xml_get_widget (glade_xml, "treeview_repo");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "treeview_repo"));
 	gtk_tree_view_set_model (GTK_TREE_VIEW (widget),
 				 GTK_TREE_MODEL (list_store));
 
@@ -541,32 +648,45 @@ main (int argc, char *argv[])
 	/* show window */
 	gtk_widget_show (main_window);
 
+	/* set the parent window if it is specified */
+	if (xid != 0) {
+		egg_debug ("Setting xid %i", xid);
+		gpk_window_set_parent_xid (GTK_WINDOW (main_window), xid);
+	}
+
 	/* focus back to the close button */
-	widget = glade_xml_get_widget (glade_xml, "button_close");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
 	gtk_widget_grab_focus (widget);
 
 	if (pk_bitfield_contain (roles, PK_ROLE_ENUM_GET_REPO_LIST)) {
 		/* get the update list */
 		gpk_repo_repo_list_refresh ();
 	} else {
-		gpk_repo_detail_cb (client, "default",
+		gpk_repo_detail_cb (client_query, "default",
 				   _("Getting software source list not supported by backend"), FALSE, NULL);
-		widget = glade_xml_get_widget (glade_xml, "treeview_repo");
+		widget = GTK_WIDGET (gtk_builder_get_object (builder, "treeview_repo"));
 		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (glade_xml, "checkbutton_detail");
+		widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_detail"));
 		gtk_widget_set_sensitive (widget, FALSE);
 	}
 
 	/* wait */
 	gtk_main ();
 
-	g_object_unref (glade_xml);
 	g_object_unref (list_store);
+out_build:
+	g_object_unref (builder);
 	g_object_unref (gconf_client);
-	g_object_unref (client);
+	g_object_unref (client_query);
 	g_object_unref (control);
+#if PK_CHECK_VERSION(0,5,1)
+	g_object_unref (pool);
+#else
+	g_ptr_array_foreach (client_array, (GFunc) g_object_unref, NULL);
+	g_ptr_array_free (client_array, TRUE);
+#endif
 unique_out:
-	g_object_unref (egg_unique);
+	g_object_unref (unique_app);
 
 	return 0;
 }
