@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -215,7 +215,7 @@ gpk_pack_resolve_package_id (const gchar *package)
 {
 	PkPackageList *list = NULL;
 	gchar *package_id = NULL;
-	gchar **packages;
+	gchar **packages = NULL;
 	GError *error = NULL;
 	const PkPackageObj *obj;
 	gboolean ret = FALSE;
