@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -43,6 +43,7 @@
 #include "gpk-common.h"
 #include "gpk-gnome.h"
 #include "gpk-dialog.h"
+#include "gpk-session.h"
 #include "gpk-error.h"
 #include "gpk-cell-renderer-size.h"
 #include "gpk-cell-renderer-info.h"
@@ -106,31 +107,10 @@ static gboolean gpk_update_viewer_get_new_update_list (void);
 static void
 gpk_update_viewer_logout (void)
 {
-	DBusGConnection *connection;
-	DBusGProxy *proxy;
-	GError *error = NULL;
-	gboolean ret;
-
-	/* get org.gnome.Session interface */
-	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
-	proxy = dbus_g_proxy_new_for_name_owner (connection, GNOME_SESSION_MANAGER_SERVICE,
-						 GNOME_SESSION_MANAGER_PATH,
-						 GNOME_SESSION_MANAGER_INTERFACE, &error);
-	if (proxy == NULL) {
-		egg_warning ("cannot connect to proxy %s: %s", GNOME_SESSION_MANAGER_SERVICE, error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* log out of the session */
-	ret = dbus_g_proxy_call (proxy, "Shutdown", &error, G_TYPE_INVALID);
-	if (!ret) {
-		egg_warning ("cannot shutdown session: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-out:
-	g_object_unref (proxy);
+	GpkSession *session;
+	session = gpk_session_new ();
+	gpk_session_logout (session);
+	g_object_unref (session);
 }
 
 /**
@@ -1814,10 +1794,36 @@ gpk_update_viewer_finished_cb (PkClient *client, PkExitEnum exit, guint runtime,
 #else
 	if (exit == PK_EXIT_ENUM_SUCCESS && role == PK_ROLE_ENUM_GET_DEPENDS) {
 #endif
+		gboolean valid;
+		GtkTreeIter iter;
+		gboolean update;
+		PkPackageId *id;
+		gchar *package_id;
+		PkPackageList *selected_list;
+
+		/* get the first iter in the list */
+		valid = gtk_tree_model_get_iter_first (model, &iter);
+
+		/* create list of selected updates */
+		selected_list = pk_package_list_new ();
+		while (valid) {
+			gtk_tree_model_get (model, &iter,
+					    GPK_UPDATES_COLUMN_SELECT, &update,
+					    GPK_UPDATES_COLUMN_ID, &package_id, -1);
+			if (update) {
+				id = pk_package_id_new_from_string (package_id);
+				pk_package_list_add (selected_list, PK_INFO_ENUM_UPDATING, id, "");
+				pk_package_id_free (id);
+			}
+			g_free (package_id);
+			valid = gtk_tree_model_iter_next (model, &iter);
+		}
+
 		/* show deps dialog */
 		list = pk_client_get_package_list (client);
-		gpk_helper_deps_update_show (helper_deps_update, list);
+		gpk_helper_deps_update_show (helper_deps_update, selected_list, list);
 		g_object_unref (list);
+		g_object_unref (selected_list);
 	}
 
 	if (role == PK_ROLE_ENUM_GET_UPDATES) {
